mycenter: mycenter

View source: R/My_functions.R

mycenterR Documentation

mycenter

Description

it helps to fix the table's heading into the center.

Usage

mycenter(text, lsp, usp)

Arguments

text

Table's heading

lsp

no. of spaces/blanks spaces in the left side of the text.

usp

no. of spaces/blanks spaces in the right side of the text.

Value

character

Examples

mycat(mycenter("This is my Table"),20,0)

RajeshMajumder97/myfunR documentation built on April 9, 2022, 1:50 a.m.