mytab_two_two_Contingency: mytab_two_two_Contingency

View source: R/My_functions.R

mytab_two_two_ContingencyR Documentation

mytab_two_two_Contingency

Description

It gives an output table for testing the significant difference between the probabilities of two independent populations,i.e., for 2x2 contingency table.

Usage

mytab_two_two_Contingency(x, y, xlev = deparse(substitute(x)))

Arguments

x

indep. character vector.

y

dep. character vector.

xlev

levels of x.

Value

Returns a data frame containing the probs., percentages along with the Chi-square Test P-Value & Fisher's Exact Test P-Value for Non-Parametric.


RajeshMajumder97/myfunR documentation built on April 9, 2022, 1:50 a.m.