| mycenter | R Documentation |
it helps to fix the table's heading into the center.
mycenter(text, lsp, usp)
text |
Table's heading |
lsp |
no. of spaces/blanks spaces in the left side of the text. |
usp |
no. of spaces/blanks spaces in the right side of the text. |
character
mycat(mycenter("This is my Table"),20,0)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.