| mytab_indep_two_Populations | R Documentation |
It gives a output table for testing the significant difference between the means of two independent populations.
mytab_indep_two_Populations(x, group, xname = deparse(substitute(x)))
x |
input dependent numeric variable. |
group |
independent character vector for the names of the two populations. |
xname |
name of the input dependent numeric variable. |
Returns a data frame containing the descriptive stat along with the indep. t-test stat., indep. t-test P Value & Non parametric(Mann Whitney U test) P Value.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.