| mytab_two_two_Contingency | R Documentation |
It gives an output table for testing the significant difference between the probabilities of two independent populations,i.e., for 2x2 contingency table.
mytab_two_two_Contingency(x, y, xlev = deparse(substitute(x)))
x |
indep. character vector. |
y |
dep. character vector. |
xlev |
levels of x. |
Returns a data frame containing the probs., percentages along with the Chi-square Test P-Value & Fisher's Exact Test P-Value for Non-Parametric.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.